@echo off
REM set MAPNAME to the name of the mapfile you wish to compile (minus extension)
REM set it to %1 if you want to run this via command line: "compile_q1 mymap"
REM set MAPDIR to the directory you wish to put the compiled map in (e.g. c:\quake\id1\maps)
REM set SRCDIR to the directory you keep the source map file in
set MAPNAME=current
set MAPDIR=c:\games\quake\id1\maps
set SRCDIR=..\q1maps

if not exist %SRCDIR%\%MAPNAME%.map goto NOFILE

echo.
echo Quake dir: %MAPDIR%
echo Map file: %MAPNAME%.map
copy %SRCDIR%\%MAPNAME%.map %MAPDIR%
echo.

choice /C 123456Q /D Q /T 60 /N /M "[1]Full [2]Fast [3]Light [4]Entities [5]Custom [6]Info [Q]Quit"
if errorlevel 7 goto RETURN
if errorlevel 6 goto INFO
if errorlevel 5 goto CUSTOM
if errorlevel 4 goto ONLYENTS
if errorlevel 3 goto LIGHT
if errorlevel 2 goto FAST
if errorlevel 1 goto FULL

REM **COMPILER OPTIONS QUICK REFERENCE**
REM See relevant readme files for full explanation of each feature and more.
REM BSP:
REM -onlyents [only compile the entity data]
REM -oldaxis [for Worldcraft 1.6 compatibility use this]
REM -transwater [enable transparent water]
REM -noents [DEBUG: remove all entities except player and world]
REM -hull n [DEBUG: select which hull to make visible]
REM VIS:
REM -level n [set the vis level. 4 is max] 
REM -fast [run fast vis only]
REM -noambient [disable ambient sounds from brushes]
REM -noambientwater [disable water ambience]
REM -noambientlava [disable lava ambience]
REM -noambientslime [disable slime ambience]
REM -noambientsky [disable sky ambience]
REM LIGHT:
REM -soft [blurs shadows slightly. Useful on bright maps with hard shadows]
REM -tyrlite95 [emulates tyrlite lighting (setting -extra4 may override this)]
REM -extra4 [full light compile]
REM -gate 1 [option that can speed up light compile a lot with minimal loss in quality]
REM -addmin [additive minimum lighting]
REM -range n [scale lighting (does not affect sunlight)]
REM -globrange [scales global lighting such as sunlight]
REM -light [min light level]
REM -maxlight [max light level]

REM if you want to modify the compile settings specifically for one map, put them here
:CUSTOM
echo.
echo
echo.
bjp_treeqbsp -oldaxis %MAPDIR%\%MAPNAME%.map %MAPDIR%\%MAPNAME%.bsp
bjp_vis -fast %MAPDIR%\%MAPNAME%.bsp
newskip %MAPDIR%\%MAPNAME%.bsp
bjp_light -gate 1 -soft %MAPDIR%\%MAPNAME%.bsp
goto END

REM only compile entity information
:ONLYENTS
echo.
echo *************ONLYENTS COMPILE*************
echo.
bjp_treeqbsp -onlyents %MAPDIR%\%MAPNAME%.map %MAPDIR%\%MAPNAME%.bsp
goto END

REM compile entity information and light
:LIGHT
echo.
echo *************LIGHT COMPILE*************
echo.
bjp_treeqbsp -onlyents %MAPDIR%\%MAPNAME%.map %MAPDIR%\%MAPNAME%.bsp
bjp_light -soft -gate 1 -extra4 -tyrlite95 %MAPDIR%\%MAPNAME%.bsp
goto END

REM fast compile only
:FAST
echo.
echo *************FAST COMPILE*************
echo.
bjp_treeqbsp -oldaxis %MAPDIR%\%MAPNAME%.map %MAPDIR%\%MAPNAME%.bsp
bjp_vis -fast %MAPDIR%\%MAPNAME%.bsp
newskip %MAPDIR%\%MAPNAME%.bsp
bjp_light -soft -gate 1 -extra4 -tyrlite95 %MAPDIR%\%MAPNAME%.bsp
goto END

REM full compile
:FULL
echo.
echo *************FULL COMPILE*************
echo.
bjp_treeqbsp -oldaxis %MAPDIR%\%MAPNAME%.map %MAPDIR%\%MAPNAME%.bsp
bjp_vis -level 4 %MAPDIR%\%MAPNAME%.bsp
newskip %MAPDIR%\%MAPNAME%.bsp
bjp_light -soft -gate 1 -extra4 -tyrlite95 %MAPDIR%\%MAPNAME%.bsp
goto END

REM show map info only
:INFO
bjp_bspinfo %MAPDIR%\%MAPNAME%.bsp
echo.
pause
goto RETURN


:NOFILE
echo.
echo ERROR: The file %SRCDIR%\%MAPNAME%.map does not exist!
echo.
pause
goto RETURN

:END
echo.
echo *************FINISHED COMPILING*************
echo.
pause

:RETURN
@echo on